@@ -1,8 +1,8 @@
 pub use crate::{
     db_schema_cred::DbSchemaCred, error::Error, query_error::QueryError, query_result::QueryResult,
     query_target::QueryTarget, result_set::ResultSet, result_set_strings::ResultSetStrings,
-    result_set_typed::ResultSetTyped, string_values::StringValues, typed_values::TypedValues,
-    value::Value,
+    result_set_typed::ResultSetTyped, ssh_tunnel_map::SshTunnelMap, string_values::StringValues,
+    typed_values::TypedValues, value::Value,
 };
 
 mod db_schema_cred;
@@ -13,6 +13,7 @@ mod query_target;
 mod result_set;
 mod result_set_strings;
 mod result_set_typed;
+mod ssh_tunnel_map;
 mod string_values;
 mod typed_values;
 mod value;
